[PATCH v3 1/3] iopoll: Add read_poll_timeout common API

Jagan Teki jagan at amarulasolutions.com
Sat May 2 09:15:01 CEST 2020


Add read_poll_timeout common API similar to Linux iopoll.

readx_poll_timeout will trigger read_poll_timeout with
proper op. This will help to extend the functionalities
like sleep_us to poll timeout in future.

This change is referenced from Linux from below commit:
commit <5f5323a14cad19323060a8cbf9d96f2280a462dd> ("iopoll:
introduce read_poll_timeout macro")

Signed-off-by: Jagan Teki <jagan at amarulasolutions.com>
---
Changes for v3:
- new patch

 include/linux/iopoll.h | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/include/linux/iopoll.h b/include/linux/iopoll.h
index ab0ae1969a..51966d83da 100644
--- a/include/linux/iopoll.h
+++ b/include/linux/iopoll.h
@@ -11,7 +11,7 @@
 #include <time.h>
 
 /**
  * readx_poll_timeout - Periodically poll an address until a condition is met or a timeout occurs
  * @op: accessor function (takes @addr as its only argument)
  * @addr: Address to poll
  * @val: Variable to read the value into
@@ -24,7 +24,7 @@
  * When available, you'll probably want to use one of the specialized
  * macros defined below rather than this macro directly.
  */
-#define readx_poll_timeout(op, addr, val, cond, timeout_us)	\
+#define read_poll_timeout(op, addr, val, cond, timeout_us)	\
 ({ \
 	unsigned long timeout = timer_get_us() + timeout_us; \
 	for (;;) { \
@@ -39,6 +39,8 @@
 	(cond) ? 0 : -ETIMEDOUT; \
 })
 
+#define readx_poll_timeout(op, addr, val, cond, timeout_us) \
+	read_poll_timeout(op, addr, val, cond, timeout_us)
 
 #define readb_poll_timeout(addr, val, cond, timeout_us) \
 	readx_poll_timeout(readb, addr, val, cond, timeout_us)
@@ -11,7 +11,7 @@
 
 /**
- * readx_poll_timeout - Periodically poll an address until a condition is met or a timeout occurs
+ * read_poll_timeout - Periodically poll an address until a condition is met or a timeout occurs
  * @op: accessor function (takes @addr as its only argument)
  * @addr: Address to poll
-- 
2.17.1



More information about the U-Boot mailing list